window.Gleam.initSearch([{"doc":"utilsbr","title":"utilsbr","content":"# utilsbr\n\n[![Package Version](https://img.shields.io/hexpm/v/utilsbr)](https://hex.pm/packages/utilsbr)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/utilsbr/)\n[![Total Download](https://img.shields.io/hexpm/dt/utilsbr)](https://hex.pm/packages/utilsbr)\n[![License](https://img.shields.io/hexpm/l/utilsbr)](https://hex.pm/packages/utilsbr)\n![Last Updated](https://img.shields.io/github/last-commit/malvfr/utilsbr)\n\nA Gleam library for Brazilian documents utilities. It provides functions to validate and generate CPF and CNPJ documents.\n\n# Installation\n\nRun the following command in your project directory:\n\n```sh\ngleam add utilsbr@0.40.0\n```\n\nThen run `gleam build` to download and compile the dependencies.\n\n````\n\n# Basic usage\n\n### Import the module\n\nImport the module and use the functions to validate and generate CPF and CNPJ documents.\n\n```gleam\nimport utilsbr/cpf\nimport utilsbr/cnpj\n\npub fn main() {\n  // Validate CPF\n  cpf.validate(&quot;873.220.050-15&quot;)\n\n}\n````\n\n### CPF functions\n\n```gleam\nimport utilsbr/cpf\n\npub fn main() {\n  // Validate CPF\n  assert True = cpf.validate(&quot;873.220.050-15&quot;)\n  assert False = cpf.validate(&quot;123.456.789-09&quot;)\n\n  // Strict Validate CPF\n\n  assert True = cpf.strict_validate(&quot;873.220.050-15&quot;)\n  assert False = cpf.strict_validate(&quot; 873.220.050-15 &quot;)\n  assert False = cpf.strict_validate(&quot; 873.220.050-15&quot;)\n\n  // Generate CPF\n\n  let cpf = cpf.generate()\n  &gt; &quot;873.220.050-15&quot;\n\n  // Format CPF\n\n  let cpf = cpf.format(&quot;87322005015&quot;)\n\n  &gt; &quot;873.220.050-15&quot;\n  // Strip CPF\n\n  let cpf = cpf.strip(&quot;873.220.050-15&quot;)\n  &gt; &quot;87322005015&quot;\n}\n```\n\n### CNPJ functions\n\n```gleam\nimport utilsbr/cnpj\n\npub fn main() {\n  // Validate CNPJ\n  assert True = cnpj.validate(&quot;84.980.771/0001-82&quot;)\n  assert False = cnpj.validate(&quot;12.345.678/0001-09&quot;)\n\n  // Strict Validate CNPJ\n\n  assert True = cnpj.strict_validate(&quot;84.980.771/0001-82&quot;)\n  assert False = cnpj.strict_validate(&quot; 84.980.771/0001-82 &quot;)\n  assert False = cnpj.strict_validate(&quot; 84.980.771/0001-82&quot;)\n\n  // Generate CNPJ\n\n  let cnpj = cnpj.generate()\n  &gt; &quot;84.980.771/0001-82&quot;\n\n  // Format CNPJ\n\n  let cnpj = cnpj.format(&quot;84980771000182&quot;)\n\n  &gt; &quot;84.980.771/0001-82&quot;\n\n  // Strip CNPJ\n\n  let cnpj = cnpj.strip(&quot;84.980.771/0001-82&quot;)\n\n  &gt; &quot;84980771000182&quot;\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/utilsbr&gt;.\n","url":"index.html"},{"doc":"cnpj/cleaner","title":"clean","content":"pub fn clean(cnpj: String) -&gt; String\n Cleans a CNPJ string by removing all non-numeric characters.\n\n This function takes a CNPJ string and uses a regular expression to remove\n any characters that are not digits (0-9). The cleaned CNPJ string is returned.\n\n # Parameters\n - `cnpj`: A string representing the CNPJ to be cleaned.\n\n # Returns\n A new string with only the numeric characters from the original CNPJ.\nSynonyms:\ncnpj/cleaner.clean\ncnpj/cleaner clean","url":"cnpj/cleaner.html#clean"},{"doc":"cnpj/cleaner","title":"cnpj/cleaner","content":"","url":"cnpj/cleaner.html"},{"doc":"utils/format","title":"all_characteres_are_equal","content":"pub fn all_characteres_are_equal(str: String) -&gt; Bool\n\nSynonyms:\nutils/format.all_characteres_are_equal\nutils/format all_characteres_are_equal","url":"utils/format.html#all_characteres_are_equal"},{"doc":"utils/format","title":"format_cnpj","content":"pub fn format_cnpj(cnpj: String) -&gt; String\n\nSynonyms:\nutils/format.format_cnpj\nutils/format format_cnpj","url":"utils/format.html#format_cnpj"},{"doc":"utils/format","title":"format_cpf","content":"pub fn format_cpf(cpf: String) -&gt; String\n\nSynonyms:\nutils/format.format_cpf\nutils/format format_cpf","url":"utils/format.html#format_cpf"},{"doc":"utils/format","title":"formatted_cnpj_regex","content":"pub fn formatted_cnpj_regex() -&gt; Regex\n\nSynonyms:\nutils/format.formatted_cnpj_regex\nutils/format formatted_cnpj_regex","url":"utils/format.html#formatted_cnpj_regex"},{"doc":"utils/format","title":"formatted_cpf_regex","content":"pub fn formatted_cpf_regex() -&gt; Regex\n\nSynonyms:\nutils/format.formatted_cpf_regex\nutils/format formatted_cpf_regex","url":"utils/format.html#formatted_cpf_regex"},{"doc":"utils/format","title":"unformatted_cnpj_regex","content":"pub fn unformatted_cnpj_regex() -&gt; Regex\n\nSynonyms:\nutils/format.unformatted_cnpj_regex\nutils/format unformatted_cnpj_regex","url":"utils/format.html#unformatted_cnpj_regex"},{"doc":"utils/format","title":"unformatted_cpf_regex","content":"pub fn unformatted_cpf_regex() -&gt; Regex\n\nSynonyms:\nutils/format.unformatted_cpf_regex\nutils/format unformatted_cpf_regex","url":"utils/format.html#unformatted_cpf_regex"},{"doc":"utils/format","title":"utils/format","content":"","url":"utils/format.html"},{"doc":"cnpj/validation","title":"calculate_first_verification_digit","content":"pub fn calculate_first_verification_digit(\n  first_twelve_digits: List(String),\n) -&gt; Int\n\nSynonyms:\ncnpj/validation.calculate_first_verification_digit\ncnpj/validation calculate_first_verification_digit","url":"cnpj/validation.html#calculate_first_verification_digit"},{"doc":"cnpj/validation","title":"calculate_second_verification_digit","content":"pub fn calculate_second_verification_digit(\n  thirteen_digits: List(String),\n) -&gt; Int\n\nSynonyms:\ncnpj/validation.calculate_second_verification_digit\ncnpj/validation calculate_second_verification_digit","url":"cnpj/validation.html#calculate_second_verification_digit"},{"doc":"cnpj/validation","title":"handle_flexible_validation","content":"pub fn handle_flexible_validation(cnpj: String) -&gt; Bool\n\nSynonyms:\ncnpj/validation.handle_flexible_validation\ncnpj/validation handle_flexible_validation","url":"cnpj/validation.html#handle_flexible_validation"},{"doc":"cnpj/validation","title":"handle_strict_validation","content":"pub fn handle_strict_validation(cnpj: String) -&gt; Bool\n\nSynonyms:\ncnpj/validation.handle_strict_validation\ncnpj/validation handle_strict_validation","url":"cnpj/validation.html#handle_strict_validation"},{"doc":"cnpj/validation","title":"cnpj/validation","content":"","url":"cnpj/validation.html"},{"doc":"cnpj/generator","title":"generate","content":"pub fn generate(formatted: Bool) -&gt; String\n Generates a CNPJ (Cadastro Nacional da Pessoa Jurídica) number.\n \n This function generates a valid CNPJ number, optionally formatted with punctuation.\n # Parameters\n - `formatted` (Bool): If `True`, the generated CNPJ will be formatted with\n   punctuation (e.g., &quot;12.345.678/0001-95&quot;). If `False`, the CNPJ will be\n   returned as a plain string of digits.\n\n # Returns\n - (String): A valid CNPJ number, optionally formatted.\nSynonyms:\ncnpj/generator.generate\ncnpj/generator generate","url":"cnpj/generator.html#generate"},{"doc":"cnpj/generator","title":"cnpj/generator","content":"","url":"cnpj/generator.html"},{"doc":"cnpj/cnpj","title":"format","content":"pub fn format(cnpj: String) -&gt; Result(String, String)\n Formats a given CNPJ (Cadastro Nacional da Pessoa Jurídica) number.\n \n This function applies the standard CNPJ formatting to the provided numeric string.\n The input string must contain exactly 14 digits.\n \n # Examples\n \n \n import utilsbr/cnpj\n \n assert &quot;12.345.678/0001-95&quot; = cnpj.format(&quot;12345678000195&quot;)\n \n \n @param cnpj The CNPJ number to be formatted as a string.\n @return A string representing the formatted CNPJ.\nSynonyms:\ncnpj/cnpj.format\ncnpj/cnpj format","url":"cnpj/cnpj.html#format"},{"doc":"cnpj/cnpj","title":"generate","content":"pub fn generate(formatted: Bool) -&gt; String\n Generates a new CNPJ (Cadastro Nacional da Pessoa Jurídica) number.\n \n This function generates a new, valid CNPJ number. The generated CNPJ can be formatted\n or unformatted based on the input parameter.\n \n # Examples\n \n \n import utilsbr/cnpj\n \n let formatted_cnpj = cnpj.generate(True)\n let unformatted_cnpj = cnpj.generate(False)\n \n assert formatted_cnpj == &quot;84.980.771/0001-82&quot;\n assert unformatted_cnpj == &quot;84980771000182&quot;\n \n \n @param formatted A boolean indicating whether the generated CNPJ should be formatted.\n @return A string representing the generated CNPJ.\nSynonyms:\ncnpj/cnpj.generate\ncnpj/cnpj generate","url":"cnpj/cnpj.html#generate"},{"doc":"cnpj/cnpj","title":"strict_validate","content":"pub fn strict_validate(cnpj: String) -&gt; Bool\n Strictly validates a given CNPJ (Cadastro Nacional da Pessoa Jurídica) number.\n \n This function performs a strict validation on the provided CNPJ string.\n Strict validation requires the input string to adhere strictly to the expected format.\n \n # Examples\n \n \n import utilsbr/cnpj\n \n assert True = cnpj.strict_validate(&quot;84.980.771/0001-82&quot;)\n assert False = cnpj.strict_validate(&quot;    84.980.771/0001-82  &quot;)\n \n \n @param cnpj The CNPJ number to be validated as a string.\n @return A boolean indicating whether the CNPJ is valid.\nSynonyms:\ncnpj/cnpj.strict_validate\ncnpj/cnpj strict_validate","url":"cnpj/cnpj.html#strict_validate"},{"doc":"cnpj/cnpj","title":"strip","content":"pub fn strip(cnpj: String) -&gt; Result(String, String)\n Strips formatting from a given CNPJ (Cadastro Nacional da Pessoa Jurídica) number.\n \n This function removes any formatting characters from the provided CNPJ string,\n leaving only the numeric digits.\n \n # Examples\n \n \n import utilsbr/cnpj\n \n assert &quot;12345678000195&quot; = cnpj.strip(&quot;12.345.678/0001-95&quot;)\n \n \n @param cnpj The CNPJ number to be stripped of formatting as a string.\n @return A string representing the unformatted CNPJ.\nSynonyms:\ncnpj/cnpj.strip\ncnpj/cnpj strip","url":"cnpj/cnpj.html#strip"},{"doc":"cnpj/cnpj","title":"validate","content":"pub fn validate(cnpj: String) -&gt; Bool\n Validates a given CNPJ (Cadastro Nacional da Pessoa Jurídica) number.\n \n This function performs a flexible validation on the provided CNPJ string.\n Flexible validation allows for some leniency in the format of the input string.\n \n # Examples\n \n \n import utilsbr/cnpj\n \n assert True = cnpj.validate(&quot;12.345.678/0001-95&quot;)\n assert False = cnpj.validate(&quot;12.345.678/0001-00&quot;)\n \n \n @param cnpj The CNPJ number to be validated as a string.\n @return A boolean indicating whether the CNPJ is valid.\nSynonyms:\ncnpj/cnpj.validate\ncnpj/cnpj validate","url":"cnpj/cnpj.html#validate"},{"doc":"cnpj/cnpj","title":"cnpj/cnpj","content":"","url":"cnpj/cnpj.html"},{"doc":"cpf/cleaner","title":"clean","content":"pub fn clean(cpf: String) -&gt; String\n Cleans a given CPF string by removing all non-numeric characters.\n\n This function takes a CPF string as input and uses a regular expression\n to remove any characters that are not digits (0-9). The cleaned CPF\n string, containing only numeric characters, is then returned.\n\n # Examples\n\n \n let cleaned_cpf = clean(&quot;123.456.789-09&quot;)\n assert cleaned_cpf == &quot;12345678909&quot;\n \n\n # Arguments\n\n * `cpf` - A string representing the CPF to be cleaned.\n\n # Returns\n\n A new string containing only the numeric characters from the input CPF.\nSynonyms:\ncpf/cleaner.clean\ncpf/cleaner clean","url":"cpf/cleaner.html#clean"},{"doc":"cpf/cleaner","title":"cpf/cleaner","content":"","url":"cpf/cleaner.html"},{"doc":"cpf/validation","title":"calculate_first_verification_digit","content":"pub fn calculate_first_verification_digit(\n  first_nine_digits: List(String),\n) -&gt; Int\n\nSynonyms:\ncpf/validation.calculate_first_verification_digit\ncpf/validation calculate_first_verification_digit","url":"cpf/validation.html#calculate_first_verification_digit"},{"doc":"cpf/validation","title":"calculate_second_verification_digit","content":"pub fn calculate_second_verification_digit(\n  ten_digits: List(String),\n) -&gt; Int\n\nSynonyms:\ncpf/validation.calculate_second_verification_digit\ncpf/validation calculate_second_verification_digit","url":"cpf/validation.html#calculate_second_verification_digit"},{"doc":"cpf/validation","title":"handle_flexible_validation","content":"pub fn handle_flexible_validation(cpf: String) -&gt; Bool\n\nSynonyms:\ncpf/validation.handle_flexible_validation\ncpf/validation handle_flexible_validation","url":"cpf/validation.html#handle_flexible_validation"},{"doc":"cpf/validation","title":"handle_strict_validation","content":"pub fn handle_strict_validation(cpf: String) -&gt; Bool\n\nSynonyms:\ncpf/validation.handle_strict_validation\ncpf/validation handle_strict_validation","url":"cpf/validation.html#handle_strict_validation"},{"doc":"cpf/validation","title":"cpf/validation","content":"","url":"cpf/validation.html"},{"doc":"cpf/generator","title":"generate","content":"pub fn generate(formatted: Bool) -&gt; String\n Generates a Brazilian CPF (Cadastro de Pessoas Físicas) number.\n \n A CPF is an 11-digit number used for tax purposes in Brazil. This function\n generates a valid CPF number, optionally formatted with punctuation.\n\n Args:\n - `formatted` (Bool): If `True`, the generated CPF will be formatted with\n   punctuation (e.g., &quot;123.456.789-09&quot;). If `False`, the CPF will be a plain\n   string of digits (e.g., &quot;12345678909&quot;).\n\n Returns:\n - `String`: The generated CPF number, optionally formatted.\nSynonyms:\ncpf/generator.generate\ncpf/generator generate","url":"cpf/generator.html#generate"},{"doc":"cpf/generator","title":"cpf/generator","content":"","url":"cpf/generator.html"},{"doc":"cpf/cpf","title":"format","content":"pub fn format(cpf: String) -&gt; Result(String, String)\n Formats a CPF number by removing any non-numeric characters and applying the standard CPF format.\n\n This function takes a CPF number as a string, cleans it by removing any non-numeric characters,\n and then formats it according to the standard CPF format.\n\n # Examples\n\n \n import utilsbr/cpf\n let formatted_cpf = cpf.format(&quot;123.456.789-09&quot;)\n assert formatted_cpf == &quot;123.456.789-09&quot;\n \n\n @param cpf The CPF number as a string.\n @return The formatted CPF number as a string.\nSynonyms:\ncpf/cpf.format\ncpf/cpf format","url":"cpf/cpf.html#format"},{"doc":"cpf/cpf","title":"generate","content":"pub fn generate(formatted: Bool) -&gt; String\n Generates a random CPF (Cadastro de Pessoas Físicas) number.\n The generated CPF number is valid according to flexible validation rules.\n # Examples\n \n import utilsbr/cpf\n \n let cpf = cpf.generate(True)\n &gt; &quot;873.220.050-15&quot;\n \n let cpf = cpf.generate(False)\n &gt; &quot;87322005015&quot;\n \n @param formatted A boolean indicating whether the generated CPF number should be formatted.\n @return A string representing the generated CPF number.\nSynonyms:\ncpf/cpf.generate\ncpf/cpf generate","url":"cpf/cpf.html#generate"},{"doc":"cpf/cpf","title":"strict_validate","content":"pub fn strict_validate(cpf: String) -&gt; Bool\n Validates a given CPF (Cadastro de Pessoas Físicas) number using strict validation rules.\n\n This function checks if the provided CPF number is valid according to strict validation rules.\n Strict validation requires the CPF number to adhere to a specific format and checksum.\n\n # Examples\n\n \n import utilsbr/cpf\n\n let valid_cpf = cpf.strict_validate(&quot;873.220.050-15&quot;)\n assert True = valid_cpf\n\n let invalid_cpf = cpf.strict_validate(&quot;  873.220.050-15  &quot;)\n assert False = invalid_cpf\n \n\n @param cpf A string representing the CPF number to be validated.\n @return A boolean indicating whether the CPF number is valid.\nSynonyms:\ncpf/cpf.strict_validate\ncpf/cpf strict_validate","url":"cpf/cpf.html#strict_validate"},{"doc":"cpf/cpf","title":"strip","content":"pub fn strip(cpf: String) -&gt; Result(String, String)\n Strips a CPF number of any non-numeric characters.\n\n This function takes a CPF number as a string and removes any non-numeric characters,\n returning only the numeric characters as a string.\n\n # Examples\n\n \n import utilsbr/cpf\n let stripped_cpf = cpf.strip(&quot;123.456.789-09&quot;)\n assert stripped_cpf == &quot;12345678909&quot;\n \n\n @param cpf The CPF number as a string.\n @return The stripped CPF number as a string containing only numeric characters.\nSynonyms:\ncpf/cpf.strip\ncpf/cpf strip","url":"cpf/cpf.html#strip"},{"doc":"cpf/cpf","title":"validate","content":"pub fn validate(cpf: String) -&gt; Bool\n Validates a given CPF (Cadastro de Pessoas Físicas) number using flexible validation rules.\n\n This function checks if the provided CPF number is valid according to flexible validation rules.\n Flexible validation allows for some leniency in the format of the CPF number.\n\n # Examples\n\n \n import utilsbr/cpf\n\n let valid_cpf = cpf.validate(&quot;161.803.571-10&quot;)\n assert True = valid_cpf\n \n let valid_cpf = cpf.validate(&quot;  161.803.571-10  &quot;)\n assert True = valid_cpf\n \n let valid_cpf = cpf.validate(&quot;161*803*571*10&quot;)\n assert True = valid_cpf\n\n let invalid_cpf = cpf.validate(&quot;151.803.571-10&quot;)\n assert False = invalid_cpf\n \n\n @param cpf A string representing the CPF number to be validated.\n @return A boolean indicating whether the CPF number is valid.\nSynonyms:\ncpf/cpf.validate\ncpf/cpf validate","url":"cpf/cpf.html#validate"},{"doc":"cpf/cpf","title":"cpf/cpf","content":"","url":"cpf/cpf.html"}]);